==> qxcommon-1.0.06-sources.jar: cn/com/startai/qxcommon/busi/huadian/bean/HDGetTeamInfoResp.java <==
package cn.com.startai.qxcommon.busi.huadian.bean;

import java.util.List;

/**
 * Created by Robin on 2019/5/25.
 * 419109715@qq.com 彬影
 */
public class HDGetTeamInfoResp extends HDGetTeamInfoReq {


    private List<DataBean> data;

    @Override
    public String toString() {
        return "HDGetTeamInfoResp{" +
                "data=" + data +
                ", custom=" + custom +
                ", product=" + product +
                ", cmd=" + cmd +
                ", result=" + result +
                '}';
    }

    public List<DataBean> getData() {
        return data;
    }

    public void setData(List<DataBean> data) {
        this.data = data;
    }

    public static class DataBean {
        /**
         * cellPhoneNumber : 17530051625
         * sex : 1
         * name : 武松
         * isTeamLeader : N
         */

        private String cellPhoneNumber;
        private int sex;
        private String name;
        private String isTeamLeader;

        @Override
        public String toString() {
            return "DataBean{" +
                    "cellPhoneNumber='" + cellPhoneNumber + '\'' +
                    ", sex=" + sex +
                    ", name='" + name + '\'' +
                    ", isTeamLeader='" + isTeamLeader + '\'' +
                    '}';
        }

        public String getCellPhoneNumber() {
            return cellPhoneNumber;
        }

        public void setCellPhoneNumber(String cellPhoneNumber) {
            this.cellPhoneNumber = cellPhoneNumber;
        }

        public int getSex() {
            return sex;
        }

        public void setSex(int sex) {
            this.sex = sex;
        }

        public String getName() {
            return name;
        }

        public void setName(String name) {
            this.name = name;
        }

        public String getIsTeamLeader() {
            return isTeamLeader;
        }

        public void setIsTeamLeader(String isTeamLeader) {
            this.isTeamLeader = isTeamLeader;
        }
    }
}

==> qxcommon-1.0.26-sources.jar: cn/com/startai/qxcommon/busi/huadian/bean/HDGetTeamInfoResp.java <==
package cn.com.startai.qxcommon.busi.huadian.bean;

import java.io.Serializable;
import java.util.List;

/**
 * Created by Robin on 2019/5/25.
 * 419109715@qq.com 彬影
 */
public class HDGetTeamInfoResp extends HDGetTeamInfoReq {


    private List<DataBean> data;

    @Override
    public String toString() {
        return "HDGetTeamInfoResp{" +
                "data=" + data +
                ", custom=" + custom +
                ", product=" + product +
                ", cmd=" + cmd +
                ", result=" + result +
                '}';
    }

    public List<DataBean> getData() {
        return data;
    }

    public void setData(List<DataBean> data) {
        this.data = data;
    }

    public static class DataBean implements Serializable {
        /**
         * cellPhoneNumber : 17530051625
         * sex : 1
         * name : 武松
         * isTeamLeader : N
         */

        private String cellPhoneNumber;
        private int sex;
        private int id;
        private String name;
        private String isTeamLeader;
        private String userId;
        private String actualEndTime;

        @Override
        public String toString() {
            return "DataBean{" +
                    "cellPhoneNumber='" + cellPhoneNumber + '\'' +
                    ", sex=" + sex +
                    ", id=" + id +
                    ", name='" + name + '\'' +
                    ", isTeamLeader='" + isTeamLeader + '\'' +
                    ", userId='" + userId + '\'' +
                    ", actualEndTime='" + actualEndTime + '\'' +
                    '}';
        }

        public String getActualEndTime() {
            return actualEndTime;
        }

        public void setActualEndTime(String actualEndTime) {
            this.actualEndTime = actualEndTime;
        }

        public String getUserId() {
            return userId;
        }

        public void setUserId(String userId) {
            this.userId = userId;
        }

        public int getId() {
            return id;
        }

        public void setId(int id) {
            this.id = id;
        }

        public String getCellPhoneNumber() {
            return cellPhoneNumber;
        }

        public void setCellPhoneNumber(String cellPhoneNumber) {
            this.cellPhoneNumber = cellPhoneNumber;
        }

        public int getSex() {
            return sex;
        }

        public void setSex(int sex) {
            this.sex = sex;
        }

        public String getName() {
            return name;
        }

        public void setName(String name) {
            this.name = name;
        }

        public String getIsTeamLeader() {
            return isTeamLeader;
        }

        public void setIsTeamLeader(String isTeamLeader) {
            this.isTeamLeader = isTeamLeader;
        }
    }
}
